==> org-lsst-ccs-ui-2.2.4-sources.jar: org/lsst/ccs/gconsole/plugins/dictionary/LsstDictionaryPlugin.java <==
package org.lsst.ccs.gconsole.plugins.dictionary;

import java.awt.Component;
import java.awt.event.ActionEvent;
import javax.swing.AbstractAction;
import javax.swing.Action;
import org.freehep.application.Application;
import org.freehep.application.mdi.PageEvent;
import org.freehep.application.studio.Studio;
import org.lsst.ccs.gconsole.base.ConsolePlugin;
import org.lsst.ccs.gconsole.Plugin;
import org.lsst.ccs.messaging.AgentMessagingLayer;


/**
 * LSST Dictionary Plugin.
 * @author Etienne
 */
@Plugin(name="LSST Dictionary Plugin",
        id="dict",
        description="LSST Dictionary Plugin allows listing available commands for a subsystem and executing them.",
        shortDescription="LSST CCS Dictionary GUI")
public class LsstDictionaryPlugin extends ConsolePlugin {

    private final String defaultConsoleName = "Dictionary Interface";
    DictionaryBusMaster dictionaryBusMaster;
    private AgentMessagingLayer messagingAccess;

    @Override
    public void initialize() {
        Action newDictionaryAction = new AbstractAction("Dictionary") {
            @Override
            public void actionPerformed(ActionEvent e) {
                createDictionaryDialog(defaultConsoleName);
            }
        };
        getServices().addMenu(newDictionaryAction, "400: CCS Tools :-1:5");
    }
    
    @Override
    public void start(){
        messagingAccess = getConsole().getMessagingAccess();
    }
    
    private void createDictionaryDialog(String name) {
        dictionaryBusMaster = new DictionaryBusMaster(messagingAccess);
        dictionaryBusMaster.initGUI();
        Studio studio = (Studio) Application.getApplication();
        studio.getPageManager().openPage(dictionaryBusMaster.getMainPane(), name, null);
        studio.getPageManager().addPageListener(event -> {
            if (event.getID() == PageEvent.PAGECLOSED){ // tab closed
                Component c = event.getPageContext().getPage();
                if (c.equals(dictionaryBusMaster.getMainPane())){
                    dictionaryBusMaster.doShutdown();
                }
            }
        });
    }
    
}

==> org-lsst-ccs-ui-2.4.1-sources.jar: org/lsst/ccs/gconsole/plugins/dictionary/LsstDictionaryPlugin.java <==
package org.lsst.ccs.gconsole.plugins.dictionary;

import java.awt.Component;
import java.awt.event.ActionEvent;
import javax.swing.AbstractAction;
import javax.swing.Action;
import org.freehep.application.Application;
import org.freehep.application.mdi.PageEvent;
import org.freehep.application.studio.Studio;
import org.lsst.ccs.gconsole.base.ConsolePlugin;
import org.lsst.ccs.gconsole.annotations.Plugin;
import org.lsst.ccs.messaging.AgentMessagingLayer;


/**
 * LSST Dictionary Plugin.
 * @author Etienne
 */
@Plugin(name="LSST Dictionary Plugin",
        id="dict",
        description="LSST Dictionary Plugin allows listing available commands for a subsystem and executing them.",
        shortDescription="LSST CCS Dictionary GUI")
public class LsstDictionaryPlugin extends ConsolePlugin {

    private final String defaultConsoleName = "Dictionary Interface";
    DictionaryBusMaster dictionaryBusMaster;
    private AgentMessagingLayer messagingAccess;

    @Override
    public void initialize() {
        Action newDictionaryAction = new AbstractAction("Dictionary") {
            @Override
            public void actionPerformed(ActionEvent e) {
                createDictionaryDialog(defaultConsoleName);
            }
        };
        getServices().addMenu(newDictionaryAction, "400: CCS Tools :-1:5");
    }
    
    @Override
    public void start(){
        messagingAccess = getConsole().getMessagingAccess();
    }
    
    private void createDictionaryDialog(String name) {
        dictionaryBusMaster = new DictionaryBusMaster(messagingAccess);
        dictionaryBusMaster.initGUI();
        Studio studio = (Studio) Application.getApplication();
        studio.getPageManager().openPage(dictionaryBusMaster.getMainPane(), name, null);
        studio.getPageManager().addPageListener(event -> {
            if (event.getID() == PageEvent.PAGECLOSED){ // tab closed
                Component c = event.getPageContext().getPage();
                if (c.equals(dictionaryBusMaster.getMainPane())){
                    dictionaryBusMaster.doShutdown();
                }
            }
        });
    }
    
}
